@@ -5,19 +5,19 @@
 
 (define s (make-session))
 
-(define x (tf-placeholder #:dtype <float> #:shape '(-1 2)))
-(define y (tf-placeholder #:dtype <float> #:shape '(-1 1)))
-(define m1 (tf-variable #:dtype <float> #:shape '(2 2)))
+(define x (tf-placeholder #:dtype <float> #:shape '(-1 2) #:name "x"))
+(define y (tf-placeholder #:dtype <float> #:shape '(-1 1) #:name "y"))
+(define m1 (tf-variable #:dtype <float> #:shape '(2 2) #:name "m1"))
 (run s '() (tf-assign m1 (tf-truncated-normal (tf-shape m1) #:dtype <float>)))
-(define b1 (tf-variable #:dtype <float> #:shape '(2)))
+(define b1 (tf-variable #:dtype <float> #:shape '(2) #:name "b1"))
 (run s '() (tf-assign b1 (fill <float> '(2) 0.0)))
 (define h1 (tf-tanh (tf-add (tf-mat-mul x m1) b1)))
 
-(define m2 (tf-variable #:dtype <float> #:shape '(2 1)))
+(define m2 (tf-variable #:dtype <float> #:shape '(2 1) #:name "m2"))
 (run s '() (tf-assign m2 (tf-truncated-normal (tf-shape m2) #:dtype <float>)))
-(define b2 (tf-variable #:dtype <float> #:shape '(1)))
+(define b2 (tf-variable #:dtype <float> #:shape '(1) #:name "b2"))
 (run s '() (tf-assign b2 (arr <float> 0)))
-(define ys (tf-sigmoid (tf-add (tf-mat-mul h1 m2) b2)))
+(define ys (tf-sigmoid (tf-add (tf-mat-mul h1 m2) b2) #:name "ys"))
 
 (define one (tf-cast 1 #:DstT <float>))
 (define cost (tf-neg (tf-mean (tf-add (tf-mul y (tf-log ys)) (tf-mul (tf-sub one y) (tf-log (tf-sub one ys)))) (arr <int> 0 1))))
